@@ -3,6 +3,8 @@
 # «mythbuntu_log_grabber» - Utility to grab diagnostic logs and data for user support
 #
 # Copyright (C) 2009, Nick Fox, for Mythbuntu
+# Copyright (C) 2009, Thomas Mashos, for Mythbuntu
+# Copyright (C) 2010, Thomas Mashos, for Mythbuntu
 #
 #
 # Mythbuntu is free software; you can redistribute it and/or modify it under
@@ -56,12 +58,15 @@ class LogGrabberPlugin(MCCPlugin):
     #Load GUI & Calculate Changes
     #
 
+    TOC = [
+    ]
+
     def __init__(self):
         import os
         #Initialize parent class
         information = {}
         information["name"] = "Log Grabber"
-        information["icon"] = "gtk-find"
+        information["icon"] = "mythbuntu-log-grabber"
         information["ui"] = "tab_log_grabber"
         """Remove Any Old Logs"""
         if os.path.exists('/tmp/mythbuntu.diag'):
@@ -81,6 +86,7 @@ class LogGrabberPlugin(MCCPlugin):
         self.changes['disk'] = True
         self.changes['version'] = True
         self.changes['hardware'] = True
+
     def applyStateToGUI(self):
         """Takes the current state information and sets the GUI
            for this plugin"""
@@ -101,21 +107,21 @@ class LogGrabberPlugin(MCCPlugin):
         """Determines what items have been modified on this plugin"""
         MCCPlugin.clearParentState(self)
         if self.sys_log_check.get_active():
-            self._markReconfigureUser('syslog', self.sys_log_check.get_active())
+            self._markReconfigureUser('Syslog', self.sys_log_check.get_active())
         if self.backend_check.get_active():
-            self._markReconfigureUser('backend', self.backend_check.get_active())
+            self._markReconfigureUser('Mythbackend Log', self.backend_check.get_active())
         if self.frontend_check.get_active():
-            self._markReconfigureUser('frontend', self.frontend_check.get_active())
+            self._markReconfigureUser('Mythfrontend Log', self.frontend_check.get_active())
         if self.xorg_check.get_active():
-            self._markReconfigureUser('xorg', self.xorg_check.get_active())
+            self._markReconfigureUser('Xorg Log', self.xorg_check.get_active())
         if self.xsession_check.get_active():
-            self._markReconfigureUser('xsession', self.xsession_check.get_active())
+            self._markReconfigureUser('Xsession Errors', self.xsession_check.get_active())
         if self.hardware_check.get_active():
-            self._markReconfigureUser('hardware', self.hardware_check.get_active())
+            self._markReconfigureUser('Installed Hardware', self.hardware_check.get_active())
         if self.version_check.get_active():
-            self._markReconfigureUser('version', self.version_check.get_active())
+            self._markReconfigureUser('Mythbuntu Version', self.version_check.get_active())
         if self.disk_space_check.get_active():
-            self._markReconfigureUser('disk', self.disk_space_check.get_active())
+            self._markReconfigureUser('Disk Space', self.disk_space_check.get_active())
             
             
     #
@@ -163,35 +169,38 @@ class LogGrabberPlugin(MCCPlugin):
     #
     def user_scripted_changes(self, reconfigure):
         for item in reconfigure:
-            if item == "syslog":
+            self.TOC.append(item)
+        self.init_log()
+        for item in reconfigure:
+            if item == "Syslog":
                 if reconfigure[item]:
                     self.emit_progress("Gathering the Syslog...", 20)
                     self.syslog()
-            elif item == "backend":
+            elif item == "Mythbackend Log":
                 if reconfigure[item]:
                     self.emit_progress("Gathering the MythTV Backend log...", 30)
                     self.mythbackend()
-            elif item == "frontend":
+            elif item == "Mythfrontend Log":
                 if reconfigure[item]:
                     self.emit_progress("Gathering the MythTV Frontend Log...", 40)
                     self.mythfrontend()
-            elif item == "xorg":
+            elif item == "Xorg Log":
                 if reconfigure[item]:
                     self.emit_progress("Gathering the Xorg Log...", 50)
                     self.xorg_log()
-            elif item == "xsession":
+            elif item == "Xsession Errors":
                 if reconfigure[item]:
                     self.emit_progress("Gathering the Xsession Log...", 60)
                     self.xsession_errors()
-            elif item == "hardware":
+            elif item == "Installed Hardware":
                 if reconfigure[item]:
                     self.emit_progress("Gathering System hardware Info...", 70)
                     self.installed_hardware()
-            elif item == "version":
+            elif item == "Mythbuntu Version":
                 if reconfigure[item]:
                     self.emit_progress("Gathering the Mythbuntu Version Info...", 80)
                     self.mythbuntu_version()
-            elif item == "disk":
+            elif item == "Disk Space":
                 if reconfigure[item]:
                     self.emit_progress("Gathering the Hard disk info...", 90)
                     self.disk_space()
@@ -210,12 +219,13 @@ class LogGrabberPlugin(MCCPlugin):
         else:
             print "Diagnostic data file not found!"
 
-    def write_log(self, section_name, data_in):
+    def write_log(self, section_name, data_in=None):
         """Builds the Actual Log File on the Local Machine"""
-        if not os.path.exists('/tmp/mythbuntu.diag'):
+        if ( section_name == "Initialize" ):
             log = open('/tmp/mythbuntu.diag', 'w')
-            log.write('=== ' + section_name + ' ===\n')
-            log.write(data_in)
+            log.write("Gathered following logs\n")
+            for TOC in self.TOC:
+                log.write('=== '+TOC+' ===\n')
             log.write('\n')
             log.close()
         else:
@@ -226,6 +236,30 @@ class LogGrabberPlugin(MCCPlugin):
             log.write('\n')
             log.close()
 
+    def tail_log(self, FILEPATH, HEADER):
+        MAXLINES=1000
+        MLP=MAXLINES/100
+        LINES=MAXLINES+MLP
+        f = open(FILEPATH, "r")
+        linestuffs = []
+        more = True
+        while more:
+            line = f.readline()
+            if line:
+                if len(linestuffs) >= LINES:
+                    del linestuffs[0:MLP]
+                linestuffs.append(line)
+            else:
+                more = False
+        f.close()
+        data_in = "=== "+FILEPATH+" ===\n"
+        for stuff in linestuffs:
+            data_in += stuff ## Change to write to logfile
+        self.write_log(HEADER,data_in)
+
+    def init_log(self):
+        self.write_log("Initialize")
+
     def installed_hardware(self):
         """Gather all Hardware Information"""
         data_in = subprocess.Popen(["/usr/bin/lspci"], stdout=subprocess.PIPE).communicate()[0]
@@ -234,39 +268,24 @@ class LogGrabberPlugin(MCCPlugin):
 
     def xorg_log(self):
         """Read in the Xorg.0.log"""
-        f = open('/var/log/Xorg.0.log')
-        data_in = f.read()
-        f.close()
-        self.write_log("Xorg Log",data_in)
+        self.tail_log('/var/log/Xorg.0.log',"Xorg Log")
 
     def xsession_errors(self):
         """Get the Xsession Errors"""
         session_log = os.environ['HOME'] + '/.xsession-errors'
-        f = open(session_log)
-        data_in = f.read()
-        f.close()
-        self.write_log("Xsession Errors",data_in)
+        self.tail_log(session_log,"Xsession Log")
 
     def syslog(self):
         """Read in the Syslog"""
-        f = open('/var/log/syslog')
-        data_in = f.read()
-        f.close()
-        self.write_log("Syslog",data_in)
+        self.tail_log('/var/log/syslog', "Syslog")
 
     def mythfrontend(self):
         """Read in the Frontend Log"""
-        f = open('/var/log/mythtv/mythfrontend.log')
-        data_in = f.read()
-        f.close()
-        self.write_log("MythtV Frontend Log",data_in)
+        self.tail_log('/var/log/mythtv/mythfrontend.log', "Mythfrontend Log")
 
     def mythbackend(self):
         """Read in the Backend Log"""
-        f = open('/var/log/mythtv/mythbackend.log')
-        data_in = f.read()
-        f.close()
-        self.write_log("MythtV Backend Log",data_in)
+        self.tail_log('/var/log/mythtv/mythbackend.log', "Mythbackend Log")
 
     def disk_space(self):
         """Gather all Disk Information"""
